Cell

Struct Cell 

pub struct Cell {
Show 43 fields pub empty: bool, pub skippable: bool, pub omitted: bool, pub skipped: bool, pub thead_in_row: bool, pub thead_in_column: bool, pub before: Option<Tokens>, pub after: Option<Tokens>, pub align: Option<Align>, pub width: Option<Dimension>, pub height: Option<Dimension>, pub depth: Option<Dimension>, pub cached_width: Option<Dimension>, pub cached_height: Option<Dimension>, pub cached_depth: Option<Dimension>, pub colspan: Option<usize>, pub colspanned: Option<usize>, pub rowspan: Option<usize>, pub rowspanned: Option<usize>, pub boxes: Option<Digested>, pub cell_type: Option<char>, pub content_class: Option<ColumnSpec>, pub content_length: Option<usize>, pub border_left: Option<usize>, pub border_right: Option<usize>, pub border_top: Option<usize>, pub border_bottom: Option<usize>, pub top_padding: Option<usize>, pub bottom_padding: Option<usize>, pub right_padding: Option<usize>, pub left_padding: Option<usize>, pub vattach: Option<String>, pub cell: Option<Node>, pub x: Option<Dimension>, pub y: Option<Dimension>, pub border: String, pub tabskip: Option<Glue>, pub lspaces: Option<Digested>, pub rspaces: Option<Digested>, pub class: Option<String>, pub has_intercol_before: bool, pub has_intercol_after: bool, pub backgroundcolor: Option<String>,
}

Fields

empty: boolskippable: boolomitted: boolskipped: boolthead_in_row: boolthead_in_column: boolbefore: Option<Tokens>after: Option<Tokens>align: Option<Align>width: Option<Dimension>height: Option<Dimension>depth: Option<Dimension>cached_width: Option<Dimension>cached_height: Option<Dimension>cached_depth: Option<Dimension>colspan: Option<usize>colspanned: Option<usize>rowspan: Option<usize>rowspanned: Option<usize>boxes: Option<Digested>cell_type: Option<char>content_class: Option<ColumnSpec>content_length: Option<usize>border_left: Option<usize>border_right: Option<usize>border_top: Option<usize>border_bottom: Option<usize>top_padding: Option<usize>bottom_padding: Option<usize>right_padding: Option<usize>left_padding: Option<usize>vattach: Option<String>cell: Option<Node>x: Option<Dimension>y: Option<Dimension>border: Stringtabskip: Option<Glue>

Perl: $$colspec{tabskip} — intercolumn glue from \halign template

lspaces: Option<Digested>

Perl: $$colspec{lspaces} — left-side spacing (incl. tabskip)

rspaces: Option<Digested>

Perl: $$colspec{rspaces} — right-side spacing

class: Option<String>

Perl: $$cell{class} — CSS class for the cell

has_intercol_before: bool

Whether this column has \lx@intercol in its before tokens (from template). Set during template building, used by nopad heuristic to distinguish regular columns (has intercolumn padding) from @{}-disabled columns.

has_intercol_after: bool

Whether this column has \lx@intercol in its after tokens (from template). Set during template building, used by nopad heuristic to distinguish regular columns (has intercolumn padding) from @{}-disabled columns.

backgroundcolor: Option<String>

Background color from \columncolor/\cellcolor (set during digestion by @setcellcolor)

Implementations

Source

impl Cell

pub fn border_at(&self, side: BorderSpec) -> Option<usize>